@@ -59,12 +59,32 @@ class CinderScenario(scenario.OpenStackScenario):
 
         return self.clients("cinder").volumes.list(detailed)
 
+    @atomic.action_timer("cinder.get_volume")
+    def _get_volume(self, volume_id):
+        """get volume detailed information.
+
+        :param volume_id: id of volume
+        :returns: class:`Volume`
+        """
+        return self.clients("cinder").volumes.get(volume_id)
+
     @atomic.action_timer("cinder.list_snapshots")
     def _list_snapshots(self, detailed=True):
         """Returns user snapshots list."""
 
         return self.clients("cinder").volume_snapshots.list(detailed)
 
+    @atomic.action_timer("cinder.list_types")
+    def _list_types(self, search_opts=None, is_public=None):
+        """Lists all volume types.
+
+        :param search_opts: Options used when search for volume types
+        :param is_public: If query public volume type
+        :returns: A list of volume types
+        """
+        return self.clients("cinder").volume_types.list(search_opts,
+                                                        is_public)
+
     def _set_metadata(self, volume, sets=10, set_size=3):
         """Set volume metadata.
 
@@ -164,6 +184,18 @@ class CinderScenario(scenario.OpenStackScenario):
         client = cinder_wrapper.wrap(self._clients.cinder, self)
         client.update_volume(volume, **update_volume_args)
 
+    @atomic.action_timer("cinder.update_readonly_flag")
+    def _update_readonly_flag(self, volume, read_only):
+        """Update the read-only access mode flag of the specified volume.
+
+        :param volume: The UUID of the volume to update.
+        :param read_only: The value to indicate whether to update volume to
+            read-only access mode.
+        :returns: A tuple of http Response and body
+        """
+        return self.clients("cinder").volumes.update_readonly_flag(
+            volume, read_only)
+
     @atomic.action_timer("cinder.delete_volume")
     def _delete_volume(self, volume):
         """Delete the given volume.
@@ -357,3 +389,67 @@ class CinderScenario(scenario.OpenStackScenario):
     def get_random_server(self):
         server_id = random.choice(self.context["tenant"]["servers"])
         return self.clients("nova").servers.get(server_id)
+
+    @atomic.action_timer("cinder.list_transfers")
+    def _list_transfers(self, detailed=True, search_opts=None):
+        """Get a list of all volume transfers.
+
+        :param detailed: If True, detailed information about transfer
+                         should be listed
+        :param search_opts: Search options to filter out volume transfers
+        :returns: list of :class:`VolumeTransfer`
+        """
+        return self.clients("cinder").transfers.list(detailed, search_opts)
+
+    @atomic.action_timer("cinder.create_volume_type")
+    def _create_volume_type(self, **kwargs):
+        """create volume type.
+
+        :param kwargs: Optional additional arguments for volume type creation
+        :returns: VolumeType object
+        """
+        kwargs["name"] = self.generate_random_name()
+        return self.admin_clients("cinder").volume_types.create(**kwargs)
+
+    @atomic.action_timer("cinder.delete_volume_type")
+    def _delete_volume_type(self, volume_type):
+        """delete a volume type.
+
+        :param volume_type: Name or Id of the volume type
+        :returns: base on client response return True if the request
+                  has been accepted or not
+        """
+        tuple_res = self.admin_clients("cinder").volume_types.delete(
+            volume_type)
+        return (tuple_res[0].status_code == 202)
+
+    @atomic.action_timer("cinder.transfer_create")
+    def _transfer_create(self, volume_id):
+        """Create a volume transfer.
+
+        :param volume_id: The ID of the volume to transfer
+        :rtype: VolumeTransfer
+        """
+        name = self.generate_random_name()
+        return self.clients("cinder").transfers.create(volume_id, name)
+
+    @atomic.action_timer("cinder.transfer_accept")
+    def _transfer_accept(self, transfer_id, auth_key):
+        """Accept a volume transfer.
+
+        :param transfer_id: The ID of the transfer to accept.
+        :param auth_key: The auth_key of the transfer.
+        :rtype: VolumeTransfer
+        """
+        return self.clients("cinder").transfers.accept(transfer_id, auth_key)
+
+    @atomic.action_timer("cinder.create_encryption_type")
+    def _create_encryption_type(self, volume_type, specs):
+        """Create encryption type for a volume type. Default: admin only.
+
+        :param volume_type: the volume type on which to add an encryption type
+        :param specs: the encryption type specifications to add
+        :return: an instance of :class: VolumeEncryptionType
+        """
+        return self.admin_clients("cinder").volume_encryption_types.create(
+            volume_type, specs)
