@@ -45,6 +45,23 @@ class CreateAndListNetworks(utils.NeutronScenario):
         self._list_networks()
 
 
+@validation.required_services(consts.Service.NEUTRON)
+@validation.required_openstack(users=True)
+@scenario.configure(context={"cleanup": ["neutron"]},
+                    name="NeutronNetworks.create_and_show_network")
+class CreateAndShowNetwork(utils.NeutronScenario):
+
+    def run(self, network_create_args=None):
+        """Create a network and show network details.
+
+        Measure the "neutron net-show" command performance.
+
+        :param network_create_args: dict, POST /v2.0/networks request options
+        """
+        network = self._create_network(network_create_args or {})
+        self._show_network(network)
+
+
 @validation.required_services(consts.Service.NEUTRON)
 @validation.required_openstack(users=True)
 @scenario.configure(context={"cleanup": ["neutron"]},
@@ -367,4 +384,21 @@ class CreateAndDeleteFloatingIps(utils.NeutronScenario):
         floating_ip_args = floating_ip_args or {}
         floating_ip = self._create_floatingip(floating_network,
                                               **floating_ip_args)
-        self._delete_floating_ip(floating_ip["floatingip"])
\ No newline at end of file
+        self._delete_floating_ip(floating_ip["floatingip"])
+
+
+@validation.required_services(consts.Service.NEUTRON)
+@validation.required_openstack(users=True)
+@scenario.configure(name="NeutronNetworks.list_agents")
+class ListAgents(utils.NeutronScenario):
+
+    def run(self, agent_args=None):
+        """List all neutron agents.
+
+        This simple scenario tests the "neutron agent-list" command by
+        listing all the neutron agents.
+
+        :param agent_args: dict, POST /v2.0/agents request options
+        """
+        agent_args = agent_args or {}
+        self._list_agents(**agent_args)
