@@ -45,6 +45,20 @@ class CinderScenarioTestCase(test.ScenarioTestCase):
         self._test_atomic_action_timer(self.scenario.atomic_actions(),
                                        "cinder.list_volumes")
 
+    def test__list_types(self):
+        return_types_list = self.scenario._list_types()
+        self.assertEqual(self.clients("cinder").volume_types.list.return_value,
+                         return_types_list)
+        self._test_atomic_action_timer(self.scenario.atomic_actions(),
+                                       "cinder.list_types")
+
+    def test__get_volume(self):
+        volume = fakes.FakeVolume()
+        self.assertEqual(self.clients("cinder").volumes.get.return_value,
+                         self.scenario._get_volume(volume.id))
+        self._test_atomic_action_timer(self.scenario.atomic_actions(),
+                                       "cinder.get_volume")
+
     def test__list_snapshots(self):
         return_snapshots_list = self.scenario._list_snapshots()
         self.assertEqual(
@@ -53,6 +67,14 @@ class CinderScenarioTestCase(test.ScenarioTestCase):
         self._test_atomic_action_timer(self.scenario.atomic_actions(),
                                        "cinder.list_snapshots")
 
+    def test__list_transfers(self):
+        return_transfers_list = self.scenario._list_transfers()
+        self.assertEqual(
+            self.clients("cinder").transfers.list.return_value,
+            return_transfers_list)
+        self._test_atomic_action_timer(self.scenario.atomic_actions(),
+                                       "cinder.list_transfers")
+
     def test__set_metadata(self):
         volume = fakes.FakeVolume()
 
@@ -145,6 +167,15 @@ class CinderScenarioTestCase(test.ScenarioTestCase):
         self._test_atomic_action_timer(self.scenario.atomic_actions(),
                                        "cinder.update_volume")
 
+    def test__update_readonly_flag(self):
+        fake_volume = mock.MagicMock()
+        self.scenario._update_readonly_flag(fake_volume, "fake_flag")
+        self.clients(
+            "cinder").volumes.update_readonly_flag.assert_called_once_with(
+            fake_volume, "fake_flag")
+        self._test_atomic_action_timer(self.scenario.atomic_actions(),
+                                       "cinder.update_readonly_flag")
+
     def test__delete_volume(self):
         cinder = mock.Mock()
         self.scenario._delete_volume(cinder)
@@ -333,3 +364,72 @@ class CinderScenarioTestCase(test.ScenarioTestCase):
         server_id = self.scenario.get_random_server()
 
         self.assertIn(server_id, servers)
+
+    def test__create_volume_type(self, **kwargs):
+        random_name = "random_name"
+        self.scenario.generate_random_name = mock.Mock(
+            return_value=random_name)
+
+        result = self.scenario._create_volume_type()
+
+        self.assertEqual(
+            self.admin_clients("cinder").volume_types.create.return_value,
+            result)
+        admin_clients = self.admin_clients("cinder")
+        admin_clients.volume_types.create.assert_called_once_with(
+            name="random_name")
+        self._test_atomic_action_timer(self.scenario.atomic_actions(),
+                                       "cinder.create_volume_type")
+
+    def test__create_encryption_type(self):
+        volume_type = mock.Mock()
+        specs = {
+            "provider": "foo_pro",
+            "cipher": "foo_cip",
+            "key_size": 512,
+            "control_location": "foo_con"
+        }
+        result = self.scenario._create_encryption_type(volume_type, specs)
+
+        self.assertEqual(
+            self.admin_clients(
+                "cinder").volume_encryption_types.create.return_value, result)
+        self.admin_clients(
+            "cinder").volume_encryption_types.create.assert_called_once_with(
+                volume_type, specs)
+        self._test_atomic_action_timer(self.scenario.atomic_actions(),
+                                       "cinder.create_encryption_type")
+
+    def test__delete_volume_type(self):
+        volume_type = mock.Mock()
+        self.scenario._delete_volume_type(volume_type)
+        admin_clients = self.admin_clients("cinder")
+        admin_clients.volume_types.delete.assert_called_once_with(
+            volume_type)
+        self._test_atomic_action_timer(self.scenario.atomic_actions(),
+                                       "cinder.delete_volume_type")
+
+    def test__transfer_create(self):
+        fake_volume = mock.MagicMock()
+        random_name = "random_name"
+        self.scenario.generate_random_name = mock.MagicMock(
+            return_value=random_name)
+        result = self.scenario._transfer_create(fake_volume.id)
+        self.assertEqual(
+            self.clients("cinder").transfers.create.return_value,
+            result)
+        self.clients("cinder").transfers.create.assert_called_once_with(
+            fake_volume.id, random_name)
+        self._test_atomic_action_timer(self.scenario.atomic_actions(),
+                                       "cinder.transfer_create")
+
+    def test__transfer_accept(self):
+        fake_transfer = mock.MagicMock()
+        result = self.scenario._transfer_accept(fake_transfer.id, "fake_key")
+        self.assertEqual(
+            self.clients("cinder").transfers.accept.return_value,
+            result)
+        self.clients("cinder").transfers.accept.assert_called_once_with(
+            fake_transfer.id, "fake_key")
+        self._test_atomic_action_timer(self.scenario.atomic_actions(),
+                                       "cinder.transfer_accept")
