@@ -25,15 +25,20 @@ BASE = "rally.plugins.openstack.scenarios.neutron.network"
 @ddt.ddt
 class NeutronNetworksTestCase(test.ScenarioTestCase):
 
+    @ddt.data(
+        {"network_create_args": {}},
+        {"network_create_args": {"name": "given-name"}},
+        {"network_create_args": {"provider:network_type": "vxlan"}}
+    )
+    @ddt.unpack
     @mock.patch("%s.CreateAndListNetworks._list_networks" % BASE)
     @mock.patch("%s.CreateAndListNetworks._create_network" % BASE)
     def test_create_and_list_networks(self,
                                       mock__create_network,
-                                      mock__list_networks):
+                                      mock__list_networks,
+                                      network_create_args):
         scenario = network.CreateAndListNetworks(self.context)
 
-        # Default options
-        network_create_args = {}
         scenario.run(network_create_args=network_create_args)
         mock__create_network.assert_called_once_with(network_create_args)
         mock__list_networks.assert_called_once_with()
@@ -41,11 +46,28 @@ class NeutronNetworksTestCase(test.ScenarioTestCase):
         mock__create_network.reset_mock()
         mock__list_networks.reset_mock()
 
-        # Explicit network name is specified
-        network_create_args = {"name": "given-name"}
+    @ddt.data(
+        {"network_create_args": {}},
+        {"network_create_args": {"name": "given-name"}},
+    )
+    @ddt.unpack
+    @mock.patch("%s.CreateAndShowNetwork._show_network" % BASE)
+    @mock.patch("%s.CreateAndShowNetwork._create_network" % BASE)
+    def test_create_and_show_network(self,
+                                     mock__create_network,
+                                     mock__show_network,
+                                     network_create_args):
+        scenario = network.CreateAndShowNetwork(self.context)
+        mock_net = mock.Mock()
+
+        mock__create_network.return_value = mock_net
         scenario.run(network_create_args=network_create_args)
+
         mock__create_network.assert_called_once_with(network_create_args)
-        mock__list_networks.assert_called_once_with()
+        mock__show_network.assert_called_once_with(mock_net)
+
+        mock__create_network.reset_mock()
+        mock__show_network.reset_mock()
 
     @mock.patch("%s.CreateAndUpdateNetworks._update_network" % BASE)
     @mock.patch("%s.CreateAndUpdateNetworks._create_network" % BASE,
@@ -209,6 +231,17 @@ class NeutronNetworksTestCase(test.ScenarioTestCase):
             subnets_per_network, router_create_args)
         scenario._list_routers.assert_called_once_with()
 
+    def test_list_agents(self):
+        agent_args = {
+            "F": "id",
+            "sort-dir": "asc"
+        }
+        scenario = network.ListAgents(self.context)
+        scenario._list_agents = mock.Mock()
+
+        scenario.run(agent_args=agent_args)
+        scenario._list_agents.assert_called_once_with(**agent_args)
+
     def test_create_and_update_routers(self):
         router_update_args = {"admin_state_up": False}
         network_create_args = {"router:external": True}
